pub enum AttributeError {
UnknownAttributeCode(TryFromPrimitiveError<AttributeCode>),
UnknownAttributeKind(TryFromPrimitiveError<AttributeKind>),
WrongBlock(AttributeCode),
TooShort,
BadString,
UnknownAttributeId(TryFromPrimitiveError<AttributeId>),
AttributeMalformed(&'static str, AttributeId),
IntAttributeUnsupported(AttributeId),
BadAttributeGroup(u32),
GroupTooShort(AttributeCode, usize),
GroupSizeMismatch(usize, usize),
Map(MapError),
}Expand description
Errors that can occur when mapping attribute blocks.
Variants
UnknownAttributeCode(TryFromPrimitiveError<AttributeCode>)
An unknown record code was seen.
UnknownAttributeKind(TryFromPrimitiveError<AttributeKind>)
An unknown attribute kind (format) was seen.
WrongBlock(AttributeCode)
The given code was seen in an unexpected block.
TooShort
The attribute couldn’t be constructed because of missing fields.
BadString
The attribute has an invalid string key or string balue.
UnknownAttributeId(TryFromPrimitiveError<AttributeId>)
The attribute has an unknown (integral) ID.
AttributeMalformed(&'static str, AttributeId)
The attribute’s ID doesn’t match the format supplied.
IntAttributeUnsupported(AttributeId)
We recognize the attribute’s ID as an integer attribute, but we don’t support it yet.
BadAttributeGroup(u32)
An entry record asked for a nonexistent attribute group.
GroupTooShort(AttributeCode, usize)
An attribute group record was too short.
GroupSizeMismatch(usize, usize)
Parsing an attribute group didn’t fully consume the underlying record fields.
Map(MapError)
A generic mapping error occured.