Struct llvm_mapper::block::strtab::Strtab[][src]

pub struct Strtab(_);
Models the STRTAB_BLOCK block.

Implementations

Get a string in the string table by its index and length.

Returns None on all of the error conditions associated with try_get.

Get a string in the string table by its index and length.

Returns an error if the requested span is invalid, or if the extracted slice isn’t a valid string.