Module record

Module record 

Structures for mapping from bitstream records to LLVM models.

Depending on their importance or complexity, not every record is given a dedicated structure or mapping implementation. Simpler records are mapped inline within their blocks.

Re-exports

pub use self::alias::*;
pub use self::comdat::*;
pub use self::datalayout::*;
pub use self::function::*;

Modules

alias
Functionality for mapping the MODULE_CODE_ALIAS record.
comdat
Functionality for mapping the MODULE_CODE_COMDAT record.
datalayout
Functionality for mapping the MODULE_CODE_DATALAYOUT record.
function
Functionality for mapping the MODULE_CODE_FUNCTION record.

Enums

RecordBlobError
Potential errors when trying to extract a blob from a record.
RecordMapError
Potential errors when mapping a single bitstream record.
RecordStringError
Potential errors when trying to extract a string from a record.