Struct llvm_mapper::unroll::UnrolledBitcode [−][src]
pub struct UnrolledBitcode { /* fields omitted */ }Expand description
A fully unrolled bitcode structure, taken from a bitstream.
Every UnrolledBitcode has a list of BitstreamModules that it contains, each of
which corresponds to a single LLVM IR module. In the simplest case, there will only be one.