Struct llvm_mapper::block::strtab::Strtab [−][src]
pub struct Strtab(_);Expand description
Models the STRTAB_BLOCK block.
Implementations
Get a string in the string table by its index and length.
Returns None on all of the error conditions associated with
try_get.